pub struct System {
pub symbol: String,
pub sector_symbol: String,
pub type: SystemType,
pub x: i32,
pub y: i32,
pub waypoints: Vec<SystemWaypoint>,
pub factions: Vec<SystemFaction>,
}Fields
symbol: StringThe symbol of the system.
sector_symbol: StringThe symbol of the sector.
type: SystemTypex: i32Relative position of the system in the sector in the x axis.
y: i32Relative position of the system in the sector in the y axis.
waypoints: Vec<SystemWaypoint>Waypoints in this system.
factions: Vec<SystemFaction>Factions that control this system.
Implementations
Sourceimpl System
impl System
pub fn new( symbol: String, sector_symbol: String, type: SystemType, x: i32, y: i32, waypoints: Vec<SystemWaypoint>, factions: Vec<SystemFaction>, ) -> System